@@ -20,7 +20,7 @@ def setup(app):
 autodoc_mock_imports = [
     'numpy',
     'matplotlib',
-    'scipy'
+    'scipy',
     'numpydoc',
 ]
 
